diff --git a/authority/server/run.js b/authority/server/run.js
index 5a88a9fb56b96b7c44f2ecbd6298dba9d869cc8f..4aeaa8ea8eda1ac6d523ae0c0337de29f31a7697 100644
--- a/authority/server/run.js
+++ b/authority/server/run.js
@@ -51,7 +51,7 @@ exports.setup = function(server) {
   var week = (7 * 24 * 60 * 60 * 1000);
   server.use(sessions({
       secret: COOKIE_SECRET,
-      session_key: "eyedeeme_state",
+      session_key: "browserid_state",
       path: '/'
   }));
 }
diff --git a/authority/static/.well-known/host-meta b/authority/static/.well-known/host-meta
index 1a2c6f388ac1d1bfe72790b1a6d14fb52b27fdf9..b577fea39d310044f4715813065b888767ea898d 100644
--- a/authority/static/.well-known/host-meta
+++ b/authority/static/.well-known/host-meta
@@ -3,9 +3,9 @@
 <XRD xmlns='http://docs.oasis-open.org/ns/xri/xrd-1.0' 
      xmlns:hm='http://host-meta.net/xrd/1.0'>
 
-  <hm:Host xmlns='http://host-meta.net/xrd/1.0'>eyedee.me</hm:Host>
+  <hm:Host xmlns='http://host-meta.net/xrd/1.0'>browserid.org</hm:Host>
 
-  <Link rel='lrdd' template='https://eyedee.me/users/{uri}.xml'></Link>
+  <Link rel='lrdd' template='https://browserid.org/users/{uri}.xml'></Link>
 
   <Link rel='other' value='something-different'></Link>
 </XRD>
diff --git a/authority/static/include.js b/authority/static/include.js
index 68287979d234e721a31022c28626056c55fa7a1d..1eb103e761a80367f0962b000d6c0999b207caca 100644
--- a/authority/static/include.js
+++ b/authority/static/include.js
@@ -7,7 +7,7 @@ if (!navigator.id) {
 
 if (!navigator.id.getVerifiedEmail || navigator.id._getVerifiedEmailIsShimmed)
 {
-  var ipServer = "https://eyedee.me";    
+  var ipServer = "https://browserid.org";
 
   // local embedded copy of jschannel: http://github.com/mozilla/jschannel 
   var Channel = (function() {
diff --git a/rp/index.html b/rp/index.html
index fc9a139ed37c63c95dd68f438f8de9c5a158be0e..8a6bb524db815e0cf527a01f4863cbc87cfbbaaa 100644
--- a/rp/index.html
+++ b/rp/index.html
@@ -79,7 +79,7 @@ a:hover { border-bottom: 2px solid black ; }
 
 </body>
 <script src="jquery-min.js"></script>
-<script src="https://eyedee.me/include.js"></script>
+<script src="https://browserid.org/include.js"></script>
 <script>
   function dumpObject(obj) {
     var htmlRep = "";
diff --git a/rp/index2.html b/rp/index2.html
index d1bc9ff2e4b693e06c661879d993fe1fe8ff0c8f..f56329c634601ba2e1846342b3e921d650bcc399 100644
--- a/rp/index2.html
+++ b/rp/index2.html
@@ -81,7 +81,7 @@ a:hover { border-bottom: 2px solid black ; }
 
 </body>
 <script src="jquery-min.js"></script>
-<script src="https://eyedee.me/include.js"></script>
+<script src="https://browserid.org/include.js"></script>
 <script>
   function dumpObject(obj) {
     var htmlRep = "";
diff --git a/run.js b/run.js
index 6daf0cecda033a09b895d707caf43d342ae8b0a4..fe9e176174952cc301fd909cd52ebf0431ea061c 100644
--- a/run.js
+++ b/run.js
@@ -143,7 +143,7 @@ var dirs = [
         path: path.join(__dirname, "rp")
     },
     {
-        name: "https://eyedee.me",
+        name: "https://browserid.org",
         path: path.join(__dirname, "authority")
     }
 ];
diff --git a/authority/static/dialog/main.js b/authority/static/dialog/main.js
index 1d97c3c7a28f5a37427399dc22c24cac0e6f8fdc..d20d725ba3b0f3ec07e5eb2aaaa002b622ca07b6 100644
--- a/authority/static/dialog/main.js
+++ b/authority/static/dialog/main.js
@@ -120,7 +120,7 @@
             url: '/wsapi/set_key?email=' + encodeURIComponent(email) + '&pubkey=' + encodeURIComponent(keypair.pub),
             success: function() {
               // update emails list and commit to local storage, then go do the next email
-              persistAddressAndKeyPair(email, keypair, "eyedee.me:443");
+              persistAddressAndKeyPair(email, keypair, "browserid.org:443");
               addNextEmail();
             },
             error: function() {
@@ -297,9 +297,9 @@
             //   'pending'  - a registration is in progress
             //   'noRegistration' - no registration is in progress
             if (status === 'complete') {
               // this is a secondary registration from eyedee.me, persist
               // email, keypair, and that fact
-              persistAddressAndKeyPair(email, keypair, "eyedee.me:443");
+              persistAddressAndKeyPair(email, keypair, "browserid.org:443");
 
               // and tell the user that everything is really quite awesome.
               runConfirmedEmailDialog(email, onsuccess, onerror);
@@ -297,9 +297,9 @@
             //   'noRegistration' - no registration is in progress
             if (status === 'complete') {
-              // this is a secondary registration from eyedee.me, persist
+              // this is a secondary registration from browserid.org, persist
               // email, keypair, and that fact